piecash and the official python bindings — Python interface to GnuCash documents 0.14.1 documentation

# piecash and the official python bindings

piecash is an alternative to the python bindings that may be bundled with gnucash (http://wiki.gnucash.org/wiki/Python_Bindings).

This page aims to give some elements of comparison between both python interfaces to better understand their relevancy to your needs. Information on the official python bindings may be incomplete (information gathered from mailing lists and wiki).

| piecash | official python bindings
--- | --- | ---
environment | Python 2.7 Python 3.3/3.4/3.5 | Python 2.7
installation | pure python package ‘pip install piecash’ | compilation (difficult on windows) binaries (available on Linux)
requires GnuCash | no | yes
gnucash files | SQL backend only | SQL backend and XML
documentation | yes (read the docs), actively developed | partial
functionalities | creation of new books read/browse objects create objects (basic) update online prices | all functionalities provided by the GnuCash C/C++ engine
to be continued | … | …